<?php
/**
 * Customizer - Options
 * 
 * @package Struninn YouTube
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnyoutube_customizer')) {
  /**
   * Registers customizer sections, controls and settings.
   * 
   * @since 1.0.0
   * 
   * @param WP_Customize_Manager $wp_customize    Customize Manager instance.
   */
  function struninnyoutube_customizer($wp_customize) {
    /**
     * Options section
     */
    $wp_customize->add_section('struninnyoutube_application_section', [
      'title'       => esc_html_x('YouTube Application', '(Customizer) YouTube Application Section - Title', 'struninnyoutube_subcount'),
      'description' => esc_html_x('From here, you can customize your YouTube channel and application information.', '(Customizer) YouTube Application Section - Description', 'struninnyoutube_subcount'),
      'priority'    => 50,
      'panel'       => 'struninnyoutube_customizer'
    ]);

    /**
     * YouTube - Channel Name
     */
    $wp_customize->add_setting('struninnyoutube_setting_channel_id', [
      'type'              => 'option',
      'capability'        => 'manage_options',
      'sanitize_callback' => 'sanitize_text_field',
      'default'           => struninnyoutube_customizer_setting_value_default_get('struninnyoutube_setting_channel_id')
    ]);
  
    $wp_customize->add_control('struninnyoutube_setting_channel_id', [
      'label'       => esc_html_x('YouTube - Channel ID', '(Customizer) YouTube Option - Label', 'struninnyoutube_subcount'),
      'description' => sprintf(
        esc_html_x('The ID of your YouTube channel: %sHow to get my channel ID%s.', '(Customizer) YouTube Option - Description', 'struninnyoutube_subcount'),
        '<a href="https://support.google.com/youtube/answer/3250431?hl=en" target="_blank">',
        '</a>'
      ),
      'type'        => 'text',
      'section'     => 'struninnyoutube_application_section'
    ]);

    /**
     * YouTube Application - API Key
     */
    $wp_customize->add_setting('struninnyoutube_setting_app_api_key', [
      'type'              => 'option',
      'capability'        => 'manage_options',
      'sanitize_callback' => 'sanitize_text_field',
      'default'           => struninnyoutube_customizer_setting_value_default_get('struninnyoutube_setting_app_api_key')
    ]);
  
    $wp_customize->add_control('struninnyoutube_setting_app_api_key', [
      'label'       => esc_html_x('YouTube Application - API Key', '(Customizer) YouTube Option - Label', 'struninnyoutube_subcount'),
      'description' => sprintf(
        esc_html_x('The API Key of your %sYouTube Application%s.', '(Customizer) YouTube Option - Description', 'struninnyoutube_subcount'),
        '<a href="https://console.cloud.google.com/" target="_blank">',
        '</a>'
      ),
      'type'        => 'password',
      'section'     => 'struninnyoutube_application_section'
    ]);
  }
}

add_action('customize_register', 'struninnyoutube_customizer');