<?php
/**
 * Customizer - Color Utils
 * 
 * @package Struninn YouTube
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnyoutube_customizer_color_options_get')) {
  /**
   * Returns color settings.
   * 
   * @since 1.0.0
   * 
   * @return array $color_settings     Color settings.
   */
  function struninnyoutube_customizer_color_options_get() {
    $color_settings = [
      /**
       * Global
       */
      '--struninnyoutube-global-primary-color' => [
        'label'   => esc_html_x('Global (Primary Color)', 'Color Option - Label', 'struninnyoutube_subcount'),
        'type'    => 'color',
        'default' => '#ff3d55'
      ],

      /**
       * Text
       */
      '--struninnyoutube-text-primary-color' => [
        'label'   => esc_html_x('Text', 'Color Option - Label', 'struninnyoutube_subcount'),
        'type'    => 'color',
        'default' => '#1f1f23'
      ],
      '--struninnyoutube-text-bold-color'    => [
        'label'   => esc_html_x('Text (Bold)', 'Color Option - Label', 'struninnyoutube_subcount'),
        'type'    => 'color',
        'default' => '#1f1f23'
      ]
    ];

    /**
     * Filters color settings.
     * 
     * @since 1.0.0
     * 
     * @param array   $color_settings
     */
    $color_settings = apply_filters('struninnyoutube_color_settings', $color_settings);

    return $color_settings;
  }
}

if (!function_exists('struninnyoutube_subcount_color_settings_filter')) {
  /**
   * Filters color settings.
   * 
   * @since 1.0.0
   * 
   * @param array $color_settings             Color settings.
   */
  function struninnyoutube_subcount_color_settings_filter($color_settings) {
    $subcount_color_settings = [
       /**
       * Border
       */
      '--struninnyoutube-border-color' => [
        'label'   => esc_html_x('Border', 'Color Option - Label', 'struninnyoutube_subcount'),
        'type'    => 'color',
        'default' => '#d8d8d8'
      ],

      /**
       * Icon
       */
      '--struninnyoutube-icon-map-color'    => [
        'label'   => esc_html_x('Map', 'Color Option - Label', 'struninnyoutube_subcount'),
        'type'    => 'color',
        'default' => '#edeff1'
      ],

      /**
       * Button
       */
      '--struninnyoutube-button-color' => [
        'label'   => esc_html_x('Button (Text)', 'Color Option - Label', 'struninnyoutube_subcount'),
        'type'    => 'color',
        'default' => '#ffffff'
      ]
    ];

    $color_settings = array_merge($color_settings, $subcount_color_settings);

    return $color_settings;
  }
}

add_filter('struninnyoutube_color_settings', 'struninnyoutube_subcount_color_settings_filter');

if (!function_exists('struninnyoutube_customizer_color_styles_get')) {
  /**
   * Returns current color style variables.
   * 
   * @since 1.0.0
   * 
   * @return string $color_styles      Current color style variables.
   */
  function struninnyoutube_customizer_color_styles_get() {
    $current_color_options = struninnyoutube_customizer_color_options_get();

    $custom_user_colors = get_option('struninnyoutube_color', []);

    foreach ($current_color_options as $color_name => $color_data) {
      $user_entered_custom_color = array_key_exists($color_name, $custom_user_colors);

      // if user entered a color for this, use it
      if ($user_entered_custom_color) {
        $color_value = $custom_user_colors[$color_name];
      } else {
      // set color default otherwise
        $color_value = $color_data['default'];
      }
      
      $custom_user_colors[$color_name] = $color_value;
    }

    $color_styles = ':root {';

    foreach ($custom_user_colors as $color_name => $color_value) {
      $color_styles .= $color_name . ': ' . $color_value . ';';
    }

    $color_styles .= '}';

    return $color_styles;
  }
}

?>