<?php
/**
 * Customizer - Settings
 * 
 * @package Struninn YouTube
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnyoutube_customizer_setting_value_default_get')) {
  /**
   * Returns a customizer setting default value.
   * 
   * @since 1.0.0
   * 
   * @param string $setting_name              Name of the customizer setting.
   * @return mixed $setting_default_value     Default value of the customizer setting if found, null otherwise.
   */
  function struninnyoutube_customizer_setting_value_default_get($setting_name) {
    $setting_default_values = [
      /**
       * YouTube Application
       */
      'struninnyoutube_setting_channel_id'    => '',
      'struninnyoutube_setting_app_api_key'   => ''
    ];

    /**
     * Filters setting default values.
     * 
     * @since 1.0.0
     * 
     * @param array   $setting_default_values
     * @param string  $setting_name
     */
    $setting_default_values = apply_filters('struninnyoutube_settings_default_values', $setting_default_values, $setting_name);

    $setting_default_value = array_key_exists($setting_name, $setting_default_values) ? $setting_default_values[$setting_name] : null;

    return $setting_default_value;
  }
}

if (!function_exists('struninnyoutube_customizer_setting_value_get')) {
  /**
   * Returns a customizer setting value.
   * 
   * @since 1.0.0
   * 
   * @param string $setting_name        Name of the customizer setting.
   * @return mixed $setting_value       Value of the customizer setting.
   */
  function struninnyoutube_customizer_setting_value_get($setting_name) {
    $setting_default_value = struninnyoutube_customizer_setting_value_default_get($setting_name);

    if (!is_null($setting_default_value)) {
      $setting_value = get_option($setting_name, $setting_default_value);
    } else {
      $setting_value = get_option($setting_name);
    }

    return $setting_value;
  }
}

if (!function_exists('struninnyoutube_subcount_settings_default_values_filter')) {
  /**
   * Filters setting default values.
   * 
   * @since 1.0.0
   * 
   * @param array $setting_default_values             Default setting values.
   */
  function struninnyoutube_subcount_settings_default_values_filter($setting_default_values) {
    $subcount_settings = [
      /**
       * Cache
       */
      'struninnyoutube_setting_subscriber_count_cache_unit' => 'days',
      'struninnyoutube_setting_subscriber_count_cache_age'  => 1
    ];

    $setting_default_values = array_merge($setting_default_values, $subcount_settings);

    return $setting_default_values;
  }
}

add_filter('struninnyoutube_settings_default_values', 'struninnyoutube_subcount_settings_default_values_filter');

?>