<?php
/**
 * Customizer - Subscriber Count
 * 
 * @package Struninn YouTube
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnyoutube_customizer_subscriber_count')) {
  /**
   * Registers customizer sections, controls and settings.
   * 
   * @since 1.0.0
   * 
   * @param WP_Customize_Manager $wp_customize    Customize Manager instance.
   */
  function struninnyoutube_customizer_subscriber_count($wp_customize) {
    /**
     * Options section
     */
    $wp_customize->add_section('struninnyoutube_subscriber_count_section', [
      'title'       => esc_html_x('Subscriber Count', '(Customizer) Subscriber Count Section - Title', 'struninnyoutube_subcount'),
      'description' => esc_html_x('From here, you can customize subscriber count options.', '(Customizer) Subscriber Count Section - Description', 'struninnyoutube_subcount'),
      'priority'    => 150,
      'panel'       => 'struninnyoutube_customizer'
    ]);

    /**
     * Videos - Cache Unit
     */
    $wp_customize->add_setting('struninnyoutube_setting_subscriber_count_cache_unit', [
      'type'              => 'option',
      'capability'        => 'manage_options',
      'sanitize_callback' => 'sanitize_text_field',
      'default'           => struninnyoutube_customizer_setting_value_default_get('struninnyoutube_setting_subscriber_count_cache_unit')
    ]);

    $wp_customize->add_control('struninnyoutube_setting_subscriber_count_cache_unit', [
      'label'       => esc_html_x('Subscriber Count - Cache Unit', '(Customizer) Subscriber Count Option - Label', 'struninnyoutube_subcount'),
      'description' => sprintf(
        esc_html_x('Unit of time used to refresh cache (e.g. if unit is "Days" and age is "1", cache is refreshed once per day / 24 hours).%sData fetched from YouTube endpoints is cached to avoid making unnecessary requests and improve loading times.%s', '(Customizer) Subscriber Count Option - Description', 'struninnyoutube_subcount'),
        '<br><br><strong>',
        '</strong>'
      ),
      'type'        => 'radio',
      'choices'     => [
        'weekly'  => esc_html__('Weekly', 'struninnyoutube_subcount'),
        'days'    => esc_html__('Days', 'struninnyoutube_subcount'),
        'hours'   => esc_html__('Hours', 'struninnyoutube_subcount'),
        'minutes' => esc_html__('Minutes', 'struninnyoutube_subcount')
      ],
      'section'     => 'struninnyoutube_subscriber_count_section'
    ]);

    /**
     * Videos - Cache Age
     */
    $wp_customize->add_setting('struninnyoutube_setting_subscriber_count_cache_age', [
      'type'              => 'option',
      'capability'        => 'manage_options',
      'sanitize_callback' => 'absint',
      'default'           => struninnyoutube_customizer_setting_value_default_get('struninnyoutube_setting_subscriber_count_cache_age')
    ]);

    $wp_customize->add_control('struninnyoutube_setting_subscriber_count_cache_age', [
      'label'       => esc_html_x('Subscriber Count - Cache Age', '(Customizer) Subscriber Count Option - Label', 'struninnyoutube_subcount'),
      'description' => sprintf(
        esc_html_x('Amount of time used to refresh cache (e.g. if unit is "Days" and age is "1", cache is refreshed once per day / 24 hours).%sIf "Weekly" unit is selected in the option above, this option has no effect (cache will refresh on Mondays).%sData fetched from YouTube endpoints is cached to avoid making unnecessary requests and improve loading times.%s', '(Customizer) Subscriber Count Option - Description', 'struninnyoutube_subcount'),
        '<br><br>',
        '<br><br><strong>',
        '</strong>'
      ),
      'type'        => 'number',
      'input_attrs' => [
        'min'   => 1,
        'step'  => 1
      ],
      'section'     => 'struninnyoutube_subscriber_count_section'
    ]);
  }
}

add_action('customize_register', 'struninnyoutube_customizer_subscriber_count');

?>