<?php
/**
 * Functions - Elementor
 * 
 * @package Struninn YouTube
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnyoutube_subcount_elementor_widgets_register')) {
  /**
   * Registers Elementor widgets.
   * 
   * @since 1.0.0
   * 
   * @param object $widgets_manager     Elementot widgets manager instance.
   */
  function struninnyoutube_subcount_elementor_widgets_register($widgets_manager) {
    require_once STRUNINNYOUTUBE_SUBCOUNT_PATH . 'includes/functions/elementor/widgets/subscriber-count/StruninnYouTube_Elementor_Widget_Channel_Subscriber_Count.php';

    $widgets_manager->register(new StruninnYouTube_Elementor_Widget_Channel_Subscriber_Count());
  }
}

add_action('elementor/widgets/register', 'struninnyoutube_subcount_elementor_widgets_register');

if (!function_exists('struninnyoutube_elementor_widget_categories_register')) {
  /**
   * Registers Elementor categories.
   * 
   * @since 1.0.0
   * 
   * @param object $elements_manager      Elementor elements manager instance.
   */
  function struninnyoutube_elementor_widget_categories_register($elements_manager) {
    $elements_manager->add_category(
      'struninnyoutube',
      [
        'title' => esc_html_x('Struninn for YouTube', '(Elementor) Struninn YouTube Category - Title', 'struninnyoutube_subcount')
      ]
    );
  }
}

add_action('elementor/elements/categories_registered', 'struninnyoutube_elementor_widget_categories_register');

if (!function_exists('struninnyoutube_elementor_widget_color_options_get')) {
  /**
   * Returns color options for an Elementor widget.
   * 
   * @since 1.0.0
   * 
   * @param string $elementor_widget_name                 Elementor widget to return color options for.
   * @return array $elementor_widget_color_options        Color options for Elementor widget.
   */
  function struninnyoutube_elementor_widget_color_options_get($elementor_widget_name) {
    $elementor_widget_applicable_color_options = [
      'channel_subscriber_count'  => [
        '--struninnyoutube-global-primary-color',
        '--struninnyoutube-border-color',
        '--struninnyoutube-text-primary-color',
        '--struninnyoutube-text-bold-color',
        '--struninnyoutube-icon-map-color',
        '--struninnyoutube-button-color'
      ],
      'channel_video_list'        => [
        '--struninnyoutube-global-primary-color',
        '--struninnyoutube-text-primary-color',
        '--struninnyoutube-text-bold-color',
        '--struninnyoutube-icon-arrow-color'
      ],
      'channel_playlist_list'     => [
        '--struninnyoutube-global-primary-color',
        '--struninnyoutube-icon-arrow-color',
        '--struninnyoutube-overlay-color',
        '--struninnyoutube-overlay-hover-color',
        '--struninnyoutube-overlay-text-color'
      ]
    ];

    $elementor_widget_color_options = [];

    $color_options = struninnyoutube_customizer_color_options_get();

    if (array_key_exists($elementor_widget_name, $elementor_widget_applicable_color_options)) {
      foreach ($elementor_widget_applicable_color_options[$elementor_widget_name] as $elementor_widget_applicable_color_option) {
        if (array_key_exists($elementor_widget_applicable_color_option, $color_options)) {
          $elementor_widget_color_options[$elementor_widget_applicable_color_option] = $color_options[$elementor_widget_applicable_color_option];
        }
      }
    }

    return $elementor_widget_color_options;
  }
}


if (!function_exists('struninnyoutube_elementor_widget_color_styles_get')) {
  /**
   * Returns style variables for Elementor widget settings.
   * 
   * @since 1.0.0
   * 
   * @param array   $elementor_widget_settings      Elementor widget settings.
   * @param array   $color_settings                 Color settings.
   * @return string $color_styles                   Color style variables.
   */
  function struninnyoutube_elementor_widget_color_styles_get($elementor_widget_settings, $color_settings) {
    $color_styles = '';

    foreach ($color_settings as $color_setting_name => $color_setting_data) {
      if (array_key_exists($color_setting_name, $elementor_widget_settings) && ($elementor_widget_settings[$color_setting_name] !== $color_setting_data['default'])) {
        $color_styles .= $color_setting_name . ':' . $elementor_widget_settings[$color_setting_name] . ';';
      }
    }

    return $color_styles;
  }
}

?>