<?php
/**
 * Functions - Elementor - Widget
 * 
 * @package Struninn YouTube
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!class_exists('StruninnYouTube_Elementor_Widget_Channel_Subscriber_Count')) {
  /**
   * Subscriber Count Elementor Widget.
   * 
   * @since 1.0.0
   */
  class StruninnYouTube_Elementor_Widget_Channel_Subscriber_Count extends \Elementor\Widget_Base {
    public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);

      wp_register_script('struninnyoutube-elementor-widget-channel-subscriber-count', STRUNINNYOUTUBE_SUBCOUNT_URL . 'js/elementor/widget/subscriber-count/channelSubscriberCount.bundle.min.js', ['elementor-frontend'], '1.0.0', true);
    }

    public function get_name() {
      return 'struninnyoutube_elementor_widget_channel_subscriber_count';
    }
  
    public function get_title() {
      return esc_html__('Channel Subscriber Count', 'struninnyoutube_subcount');
    }
  
    public function get_icon() {
      return 'eicon-counter-circle';
    }
  
    public function get_categories() {
      return ['struninnyoutube'];
    }
  
    public function get_keywords() {
      return ['struninn', 'struninnyoutube', 'youtube', 'channel', 'subscriber'];
    }
  
    protected function register_controls() {
      $this->start_controls_section(
        'struninnyoutube_channel_subscriber_count_content',
        [
          'label' => esc_html__('Content', 'struninnyoutube_subcount'),
          'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
        ]
      );

      $this->add_control(
        'struninnyoutube_channel_subscriber_count_template',
        [
          'label'   => esc_html__('Template', 'struninnyoutube_subcount'),
          'type'    => \Elementor\Controls_Manager::SELECT,
          'default' => 'v1',
          'options' => [
            'v1' => esc_html__('V1', 'struninnyoutube_subcount'),
            'v2' => esc_html__('V2', 'struninnyoutube_subcount'),
            'v3' => esc_html__('V3', 'struninnyoutube_subcount'),
            'v4' => esc_html__('V4', 'struninnyoutube_subcount')
          ]
        ]
      );

      $this->add_control(
        'struninnyoutube_channel_subscriber_count_hide_subscribe_button',
        [
          'label'         => esc_html__('Subscribe Button', 'struninnyoutube_subcount'),
          'type'          => \Elementor\Controls_Manager::SWITCHER,
          'return_value'  => 'yes',
          'default'       => 'yes'
        ]
      );

      $this->end_controls_section();

      $color_settings = struninnyoutube_elementor_widget_color_options_get('channel_subscriber_count');

      $this->start_controls_section(
        'struninnyoutube_channel_subscriber_count_style',
        [
          'label' => esc_html__('Colors', 'struninnyoutube_subcount'),
          'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ]
      );

      foreach ($color_settings as $color_setting_name => $color_setting_data) {
        $this->add_control(
          $color_setting_name,
          [
            'label'   => $color_setting_data['label'],
            'type'    => \Elementor\Controls_Manager::COLOR,
            'default' => $color_setting_data['default']
          ]
        );
      }
    }
  
    protected function render() {
      $settings = $this->get_settings_for_display();

      $color_settings = struninnyoutube_elementor_widget_color_options_get('channel_subscriber_count');

      $styles = struninnyoutube_elementor_widget_color_styles_get($settings, $color_settings);

      $args = [
        'styles'                => $styles,
        'template'              => $settings['struninnyoutube_channel_subscriber_count_template'],
        'hide_subscribe_button' => $settings['struninnyoutube_channel_subscriber_count_hide_subscribe_button'] !== 'yes'
      ];
    
      struninnyoutube_template_channel_subscriber_count($args);
    }

    public function get_script_depends() {
      return ['struninnyoutube-elementor-widget-channel-subscriber-count'];
    }
  }
}

?>