<?php
/**
 * Functions - Utils
 * 
 * @package Struninn YouTube
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnyoutube_access_keys_get')) {
  /**
   * Returns YouTube application access keys.
   * 
   * @since 1.0.0
   * 
   * @return array $access_keys {
   *   @type string $api_key        YouTube application API Key.
   * }
   */
  function struninnyoutube_access_keys_get() {
    $access_keys = [
      'api_key' => struninnyoutube_customizer_setting_value_get('struninnyoutube_setting_app_api_key')
    ];

    return $access_keys;
  }
}

if (!function_exists('struninnyoutube_channel_id_get')) {
  /**
   * Returns YouTube channel id.
   * 
   * @since 1.0.0
   * 
   * @return string $channel_id       YouTube channel id.
   */
  function struninnyoutube_channel_id_get() {
    $channel_id = struninnyoutube_customizer_setting_value_get('struninnyoutube_setting_channel_id');

    return $channel_id;
  }
}

if (!function_exists('struninnyoutube_channel_subscribe_url_get')) {
  /**
   * Returns YouTube channel subscribe URL.
   * 
   * @since 1.0.0
   * 
   * @return string $channel_subscribe_url        YouTube channel subscribe URL.
   */
  function struninnyoutube_channel_subscribe_url_get() {
    $channel_subscribe_url = '#';

    $channel_id = struninnyoutube_channel_id_get();

    if ($channel_id) {
      $channel_subscribe_url = 'https://www.youtube.com/channel/' . $channel_id . '?sub_confirmation=1';
    }

    return $channel_subscribe_url;
  }
}

if (!function_exists('struninnyoutube_subcount_constants_get')) {
  /**
   * Returns plugin constants as a string.
   * 
   * @since 1.0.0
   * 
   * @return string $constants        Plugin constants.
   */
  function struninnyoutube_subcount_constants_get() {
    $constants_values = [
      'restURL'             => get_rest_url(null, 'struninnyoutube/v1/'),
      'channelSubscribeURL' => struninnyoutube_channel_subscribe_url_get()
    ];

    $constants = 'const struninnyoutubeSubcountConstants = ' . json_encode($constants_values) . ';';

    return $constants;
  }
}

?>