<?php
/**
 * Functions - Template - Global
 * 
 * @package Struninn YouTube
 * 
 * @since 1.0.0
 * 
 * @author Odin Design Themes (https://odindesignthemes.com/)
 * 
 */

if (!function_exists('struninnyoutube_template_channel_subscriber_count_args_default_get')) {
  /**
   * Returns channel subscriber count template default args.
   * 
   * @since 1.0.0
   * 
   * @return array $channel_subscriber_count_args_default        Default channel subscriber count template args.
   */
  function struninnyoutube_template_channel_subscriber_count_args_default_get() {
    $channel_subscriber_count_args_default = [
      'additional_wrapper_classes'  => [],
      'template'                    => 'v1',
      'hide_subscribe_button'       => false,
      'styles'                      => false
    ];

    return $channel_subscriber_count_args_default;
  }
}

if (!function_exists('struninnyoutube_template_channel_subscriber_count_get')) {
  /**
   * Returns channel subscriber count HTML.
   * 
   * @since 1.0.0
   * 
   * @param array $args {
   *   @type array  $additional_wrapper_classes     Additional classes for the wrapper.
   *   @type string $template                       Channel subscriber count template, one of: 'v1', 'v2', 'v3', 'v4'. Default: 'v1'.
   *   @type string $hide_subscribe_button          True to hide subscribe button, false otherwise. Default: false.
   *   @type string $styles                         Additional inline styles for the wrapper. Default: false.
   * }
   * @return string $template                       Channel videos HTML.
   */
  function struninnyoutube_template_channel_subscriber_count_get($args = []) {
    $defaults = struninnyoutube_template_channel_subscriber_count_args_default_get();

    $options = array_merge($defaults, $args);

    /**
     * Filters template wrapper additional classes.
     * 
     * @since 1.0.0
     * 
     * @param array $additional_wrapper_classes
    */
    $additional_wrapper_classes = apply_filters('struninnyoutube_template_channel_subscriber_count_additional_wrapper_classes', $options['additional_wrapper_classes']);
    $additional_wrapper_classes = implode(' ', $additional_wrapper_classes);

    ob_start();

  ?>
    <!-- STRUNINN SUBSCRIBER COUNT -->
    <div  class="struninnyoutube-subscriber-count <?php echo esc_attr($additional_wrapper_classes); ?>"
          data-template="<?php echo esc_attr($options['template']); ?>"
          data-hide-subscribe-button="<?php echo esc_attr($options['hide_subscribe_button']); ?>"
          style="<?php echo esc_attr($options['styles']); ?>"
    >
    </div>
    <!-- /STRUNINN SUBSCRIBER COUNT -->
  <?php

    $template = ob_get_clean();

    return $template;
  }
}

if (!function_exists('struninnyoutube_template_channel_subscriber_count')) {
  /**
   * Displays channel subscriber count HTML.
   * 
   * @since 1.0.0
   * 
   * @param array $args         channel subscriber count template args.
   */
  function struninnyoutube_template_channel_subscriber_count($args = []) {
    $channel_subscriber_count = struninnyoutube_template_channel_subscriber_count_get($args);

    $channel_subscriber_count_allowed_html = [
      'div' => [
        'class'                       => [],
        'data-template'               => [],
        'data-hide-subscribe-button'  => [],
        'style'                       => []
      ]
    ];
    
    echo wp_kses($channel_subscriber_count, $channel_subscriber_count_allowed_html);
  }
}

?>