import React, { useState, useEffect } from 'react';

import ErrorMessage from '../error/ErrorMessage';

import Loader from '../loader/Loader';

import youtubeEndpointDataGet from '../../endpoint/endpoint';

import { getSubscriberCountTemplate } from './subscriberCount-utils';

const SubscriberCount = (props) => {
  const [channelData, setChannelData] = useState(false);
  const [loadingChannelData, setLoadingChannelData] = useState(false);
  const [errorData, setErrorData] = useState({});

  const getChannelData = () => {
    const channelData = youtubeEndpointDataGet('channel');

    setLoadingChannelData(true);

    channelData
    .then((response) => {
      // console.log('SubscriberCount - getChannelData - response: ', response);

      let data = response;

      if (response.length) {
        data = response[0];
      }

      if (data.message) {
        setErrorData(data);
      } else {
        setChannelData(data);
      }
    })
    .catch((error) => {
      // console.error('SubscriberCount - getChannelData - error: ', error);
    })
    .finally(() => {
      setLoadingChannelData(false);
    });
  };

  useEffect(() => {
    getChannelData();
  }, []);

  const template = props.template || 'v1';
  const SubscriberCountTemplate = getSubscriberCountTemplate(template);

  return (
    <React.Fragment>
    {
      loadingChannelData &&
        <Loader />
    }
    {
      !loadingChannelData &&
        <React.Fragment>
        {
          channelData &&
            <SubscriberCountTemplate data={channelData} hideSubscribeButton={props.hideSubscribeButton} />
        }
        {
          !channelData &&
            <ErrorMessage data={errorData} />
        }
        </React.Fragment>
    }
    </React.Fragment>
  );
};

export { SubscriberCount as default };